clearvars
close all
clc
%% Data
Cf = 5; % Propellant cost [$/kg] 2020

Wf = 11200; % Propellant mass [kg]

WGTO = 56000; % Gross Take-Off Weight [kg]

WAV = 1000; % Avionics mass [kg]

WENG = 2280; % Single engine mass [kg]

N_eng = 2; % Number of engines
Kr = 0.08; % Propellant reserve percentage
LF = 0.7; % Load factor
Rt = 9000; % Operational range [km]
Pax = 18; % Number of passengers
W_per_pax = 100; % Mass per passenger [kg]

M = 5; % Cruise Mach number
FlightTime = 2; % Flight time [hr]
h = 24000; % Cruise altitude [m]
CPI_1972 = 41.85; % Consumer Price Index 1972

CPI_2021 = 270.97; % Consumer Price Index 2021
IR = 0.02; % Insurance rate per year

CHST = 233e6; % Aircraft cost [$] 2021
CTJ = 37e6; % Engine cost [$] 2021
U = 2800; % Utilization [block hr/years]
Ld = 10; % Life time [years]


rl = 5.30; % Maintenance labor rate [$/hr] 1972
Thrust_eng = 325e3; % One engine thrust at take-off [N]
g = 9.81; % Gravity acceleration [m/s2]
KLTJ = 2; % Complexity factor for Labor high-speed TJ with reference to subsonic
KMTJ = 2; % Complexity factor for Material high-speed TJ with reference to subsonic

%% Derived variables
Wpl = Pax*W_per_pax; % Payload mass [kg]
PMF = Wf/WGTO; % Propellant mass fraction
PyMF = Wpl/WGTO; % Payload mass fraction
Wf_t = Wf/1000; % Propellant mass [ton]
Wpl_t = Wpl/1000; % Payload mass [ton]
WGTO_t = WGTO/1000; % Gross Take-Off Weight [ton]
WAF = WGTO-WAV-N_eng*WENG-Wpl-Wf; % Airframe mass without engines & avio [kg]

Rt_nm = Rt/1.852; % Operational range [nm]
% [T, c, p, rho] = atmosisa(h);
c=297.75; %Sound velocity [m/s]
Vcr = M*c; % Cruise speed [m/s]
FlightTime_s = 3600*FlightTime; % Flight time [s]
BlockTime = 1.25*FlightTime; %ore
VB = Rt*1000/(BlockTime*3600); % Block speed [m/s];

CEF = CPI_2021/CPI_1972; % Cost Escalation Factor
Thrust_TOT = N_eng*Thrust_eng; % Total Thrust at Take-off [N]
TW_GTO = Thrust_TOT/(WGTO*g); % Thrust-to-Weight ratio at Take-Off 

%% DOC CERs (NASA modified IATA)
% Fuel
DOC_fuel = (1460*Cf*PMF*(1-Kr))/(LF*PyMF*Rt); % DOC fuel [$/(ton nm)]
DOC_fuel_flight = DOC_fuel*Wpl_t*Rt_nm; % DOC fuel [$/flight]
DOC_fuel_PKM = DOC_fuel_flight/(LF*Pax*Rt); % DOC fuel [$/(pax km)]

% Crew
DOC_crew = (320/WGTO)/(0.725*LF*PyMF*M*VB/Vcr)*CEF; % DOC crew [$/(ton nm)]
DOC_crew_flight = DOC_crew*Wpl_t*Rt_nm; % DOC crew [$/flight]
DOC_crew_PKM = DOC_crew_flight/(LF*Pax*Rt); % DOC crew [$/(pax km)]

% Insurance
DOC_insurance = (IR*CHST/WGTO)/(0.725*LF*PyMF*M*VB/Vcr*U); % DOC Insurance [$/(ton nm)]
DOC_insurance_flight = DOC_insurance*Wpl_t*Rt_nm; % DOC Insurance [$/flight]
DOC_insurance_PKM = DOC_insurance_flight/(LF*Pax*Rt); % DOC Insurance [$/(pax km)]

% Depreciation
DOC_depreciation = (1.1*(CHST/WGTO)+0.3*(CTJ/WGTO))/(0.725*LF*PyMF*M*VB/Vcr*U*Ld); % DOC Depreciation [$/(ton nm)]
DOC_depreciation_flight = DOC_depreciation*Wpl_t*Rt_nm; % DOC Depreciation [$/flight]
DOC_depreciation_PKM = DOC_depreciation_flight/(LF*Pax*Rt); % DOC Depreciation [$/(pax km)]

% Maintenance Airframe Labor
DOC_maintenance_AF_L = ((3.22+1.93*FlightTime)*(0.05*(WAF/WGTO+WAV/WGTO)+0.009)*(rl*M^0.5))/(LF*PyMF*Rt)*CEF; % DOC Maintenance Airframe Labor [$/(ton nm)]
DOC_maintenance_AF_L_flight = DOC_maintenance_AF_L*Wpl_t*Rt_nm; % DOC Maintenance Airframe Labor [$/flight]
DOC_maintenance_AF_L_PKM = DOC_maintenance_AF_L_flight/(LF*Pax*Rt); % DOC Maintenance Airframe Labor [$/(pax km)]

% Maintenance Airframe Material
DOC_maintenance_AF_M = ((4.52*FlightTime+9.04)*(CHST/WGTO-CTJ/WGTO))/(LF*PyMF*Rt*1000); % DOC Maintenance Airframe Material [$/(ton nm)]
DOC_maintenance_AF_M_flight = DOC_maintenance_AF_M*Wpl_t*Rt_nm; % DOC Maintenance Arfirame Material [$/flight]
DOC_maintenance_AF_M_PKM = DOC_maintenance_AF_M_flight/(LF*Pax*Rt); % DOC Maintenance Airframe Material [$/(pax km)]

% Maintenance TJ Labor
DOC_maintenance_TJ_L = (TW_GTO*(1+0.3*FlightTime)*(((8.60/(Thrust_eng/1000))+0.087)*rl*KLTJ))/(LF*PyMF*Rt)*CEF; % DOC Maintenance TJ Labor [$/(ton nm)]
DOC_maintenance_TJ_L_flight = DOC_maintenance_TJ_L*Wpl_t*Rt_nm; % DOC Maintenance TJ Labor [$/flight]
DOC_maintenance_TJ_L_PKM = DOC_maintenance_TJ_L_flight/(LF*Pax*Rt); % DOC Maintenance TJ Labor [$/(pax km)]

% Maintenance TJ Material
DOC_maintenance_TJ_M = (CTJ/WGTO*(0.011*FlightTime+0.029)*KMTJ)/(LF*PyMF*Rt); % DOC Maintenance TJ Material [$/(ton nm)]
DOC_maintenance_TJ_M_flight = DOC_maintenance_TJ_M*Wpl_t*Rt_nm; % DOC Maintenance TJ Material [$/flight]
DOC_maintenance_TJ_M_PKM = DOC_maintenance_TJ_M_flight/(LF*Pax*Rt); % DOC Maintenance TJ Material [$/(pax km)]

DDOC_maintenance=DOC_maintenance_TJ_M+DOC_maintenance_TJ_L+DOC_maintenance_AF_M+DOC_maintenance_AF_L;
%% Post-Processing
TOT_CostTonMile = DOC_fuel + DOC_crew + DOC_insurance + ...
    DOC_depreciation + DOC_maintenance_AF_L + ...
    DOC_maintenance_AF_M + DOC_maintenance_TJ_L + ...
    DOC_maintenance_TJ_M;

TOT_CostPaxKM = DOC_fuel_PKM + DOC_crew_PKM + DOC_insurance_PKM + ...
    DOC_depreciation_PKM + DOC_maintenance_AF_L_PKM + ...
    DOC_maintenance_AF_M_PKM + DOC_maintenance_TJ_L_PKM + ...
    DOC_maintenance_TJ_M_PKM;

TOT_CostPerFlight = DOC_fuel_flight + DOC_crew_flight + DOC_insurance_flight + ...
    DOC_depreciation_flight + DOC_maintenance_AF_L_flight + ...
    DOC_maintenance_AF_M_flight + DOC_maintenance_TJ_L_flight + ...
    DOC_maintenance_TJ_M_flight;

CostPerFlight = [DOC_fuel_flight, DOC_crew_flight, DOC_insurance_flight, ...
    DOC_depreciation_flight, DOC_maintenance_AF_L_flight, ...
    DOC_maintenance_AF_M_flight, DOC_maintenance_TJ_L_flight, ...
    DOC_maintenance_TJ_M_flight]';

CostTonMile = [DOC_fuel, DOC_crew, DOC_insurance, ...
    DOC_depreciation, DOC_maintenance_AF_L, ...
    DOC_maintenance_AF_M, DOC_maintenance_TJ_L, ...
    DOC_maintenance_TJ_M]';

CostPaxKM = [DOC_fuel_PKM, DOC_crew_PKM, DOC_insurance_PKM, ...
    DOC_depreciation_PKM, DOC_maintenance_AF_L_PKM, ...
    DOC_maintenance_AF_M_PKM, DOC_maintenance_TJ_L_PKM, ...
    DOC_maintenance_TJ_M_PKM]';

pie(CostPerFlight)
legend('Fuel','Crew','Insurance','Depreciation',...
    'Maintenance AF L','Maintenance AF M',...
    'Maintenance TJ L','Maintenance TJ M')

%% Export
filename = 'CostComparison.xlsx';
writematrix(CostTonMile,filename,'Sheet',1,'Range','B2:B9')
writematrix(CostPaxKM,filename,'Sheet',1,'Range','F2:F9')
writematrix(CostPerFlight,filename,'Sheet',1,'Range','J2:J9')
